API docs for “spamfighter.core.message.message.Message”

# Class s.c.m.m.Message(object):

Part of spamfighter.core.message.message View Source View In Hierarchy

Known subclasses: spamfighter.core.message.message.TaggedMessage

Сообщение - основная единица обработки для Спамоборца.

Сообщение обладает тремя основными свойствами:

- от кого;
- кому;
- текст;
- время отправки.

Структурно поля "от кого" и "кому" ничем не отличаются, они описывают адресанта и адресата сообщения, соответственно. Поле "кому" может отсутствовать (например, если это сообщение - девиз пользователя на своей странице). Поля "от кого" и "кому" состоят из атрибутов (`IAttribute`).

Instance Variables | _attributes | хэш (по имени) атрибутов сообщения (type: `dict` )

Method | __init__ | Конструктор.
Method | get | Получить атрибут по имени.
Method | __getitem__ | Undocumented
Method | __iter__ | Undocumented
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented
Method | _putAttr | Добавить атрибут к сообщению.

def __init__(self, attributes): (source)
overridden in spamfighter.core.message.message.TaggedMessage
Конструктор.

Parameters | attributes | атрибуты сообщения (type: `list(``IAttribute``)` )

def _putAttr(self, attribute): (source)
Добавить атрибут к сообщению.

Parameters | attribute | атрибут

def get(self, name): (source)
Получить атрибут по имени.

Parameters | name | имя атрибута (type: `str` )
Returns | атрибут (type: `IAttribute` )

def __getitem__(self, name): (source)
Undocumented
def __iter__(self): (source)
Undocumented
def __eq__(self, other): (source)
overridden in spamfighter.core.message.message.TaggedMessage
Undocumented
def __repr__(self): (source)
overridden in spamfighter.core.message.message.TaggedMessage
Undocumented